@@ -20,18 +20,20 @@ import pkg_resources
 from collections import namedtuple
 from docutils import nodes
 from sphinx import addnodes
+from sphinx.util import logging
 from sphinx.util.osutil import ensuredir
 
 import packetdiag.utils.rst.nodes
 import packetdiag.utils.rst.directives
 from blockdiag.utils.bootstrap import detectfont, Application
-from blockdiag.utils.compat import u, string_types
 from blockdiag.utils.fontmap import FontMap
 from blockdiag.utils.rst.directives import with_blockdiag
 
 # fontconfig; it will be initialized on `builder-inited` event.
 fontmap = None
 
+logger = logging.getLogger(__name__)
+
 
 class packetdiag_node(packetdiag.utils.rst.nodes.packetdiag):
     def to_drawer(self, image_format, builder, **kwargs):
@@ -92,7 +94,7 @@ def resolve_reference(builder, href):
     if href is None:
         return None
 
-    pattern = re.compile(u("^:ref:`(.+?)`"), re.UNICODE)
+    pattern = re.compile("^:ref:`(.+?)`", re.UNICODE)
     matched = pattern.search(href)
     if matched is None:
         return href
@@ -110,7 +112,7 @@ def resolve_reference(builder, href):
             else:
                 return xref['refuri']
         else:
-            builder.warn('undefined label: %s' % refid)
+            logger.warning('undefined label: %s', refid)
             return None
 
 
@@ -212,13 +214,13 @@ def html_visit_packetdiag(self, node):
 
         msg = ("packetdiag error: UnicodeEncodeError caught "
                "(check your font settings)")
-        self.builder.warn(msg)
+        logger.warning(msg)
         raise nodes.SkipNode
     except Exception as exc:
         if self.builder.config.packetdiag_debug:
             traceback.print_exc()
 
-        self.builder.warn('dot code %r: %s' % (node['code'], str(exc)))
+        logger.warning('dot code %r: %s', node['code'], exc)
         raise nodes.SkipNode
 
 
@@ -253,7 +255,7 @@ def get_image_format_for(builder):
 def on_builder_inited(self):
     # show deprecated message
     if self.builder.config.packetdiag_tex_image_format:
-        self.builder.warn('packetdiag_tex_image_format is deprecated. Use packetdiag_latex_image_format.')
+        logger.warning('packetdiag_tex_image_format is deprecated. Use packetdiag_latex_image_format.')
 
     # initialize fontmap
     global fontmap
@@ -261,19 +263,19 @@ def on_builder_inited(self):
     try:
         fontmappath = self.builder.config.packetdiag_fontmap
         fontmap = FontMap(fontmappath)
-    except:
+    except Exception:
         fontmap = FontMap(None)
 
     try:
         fontpath = self.builder.config.packetdiag_fontpath
-        if isinstance(fontpath, string_types):
+        if isinstance(fontpath, str):
             fontpath = [fontpath]
 
         if fontpath:
             config = namedtuple('Config', 'font')(fontpath)
             fontpath = detectfont(config)
             fontmap.set_default_font(fontpath)
-    except:
+    except Exception:
         pass
 
 
@@ -287,7 +289,7 @@ def on_doctree_resolved(self, doctree, docname):
         if self.builder.config.packetdiag_debug:
             traceback.print_exc()
 
-        self.builder.warn('packetdiag error: %s' % exc)
+        logger.warning('packetdiag error: %s', exc)
         for node in doctree.traverse(packetdiag_node):
             node.parent.remove(node)
 
@@ -308,7 +310,7 @@ def on_doctree_resolved(self, doctree, docname):
             if self.builder.config.packetdiag_debug:
                 traceback.print_exc()
 
-            self.builder.warn('dot code %r: %s' % (node['code'], str(exc)))
+            logger.warning('dot code %r: %s', node['code'], exc)
             node.parent.remove(node)
 
 
